==> org-lsst-ccs-subsystem-rafts-gui-1.10.4-sources.jar: org/lsst/ccs/subsystem/rafts/ui/jas/RaftsConsolePlugin.java <==
package org.lsst.ccs.subsystem.rafts.ui.jas;

import javax.swing.JComponent;
import org.lsst.ccs.bus.data.AgentInfo;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.base.OptionalPage;
import org.lsst.ccs.subsystem.rafts.data.RaftsAgentProperties;
import org.lsst.ccs.subsystem.rafts.ui.RaftsControlGui;
import org.lsst.ccs.subsystem.rafts.ui.RaftsMonitorGui;

/**
 *
 * @author tonyj
 */
@Plugin(name = "CCS Rafts Console Plugin",
        description = "CCS Rafts Console Plugin")
public class RaftsConsolePlugin extends ConsolePlugin {

    
    private final OptionalPage raftsMonitoringOptionalPage = new RaftsConsolePlugin.RaftsMonitoringOptionalPage();
    private final OptionalPage raftsControlsOptionalPage = new RaftsConsolePlugin.RaftsControlsOptionalPage();

    @Override
    public void initialize() {
        Console.getConsole().addOptionalPage(raftsMonitoringOptionalPage);
        Console.getConsole().addOptionalPage(raftsControlsOptionalPage);
    }


    static class RaftsMonitoringOptionalPage implements OptionalPage {

        @Override
        public boolean isAutoOpen() {
            return false;
        }

        @Override
        public String getPath() {
            return "CCS Subsystems/Rafts/Monitoring";
        }

        @Override
        public String getPage(AgentInfo agent) {
            if (agent.hasAgentProperty(RaftsAgentProperties.RAFT_TYPE_AGENT_PROPERTY) ) {
                return agent.getName();
            }
            return null;
        }

        @Override        
        public JComponent open(AgentInfo agent, JComponent existingComponent) {
            String agentName = agent.getName();
            RaftsMonitorGui gui = new RaftsMonitorGui(agentName);
            gui.initGui();
            return gui.getGuiLayout();
        }

    }
    
    static class RaftsControlsOptionalPage implements OptionalPage {

        @Override
        public boolean isAutoOpen() {
            return false;
        }

        @Override
        public String getPath() {
            return "CCS Subsystems/Rafts/Controls";
        }

        @Override
        public String getPage(AgentInfo agent) {
            if (agent.hasAgentProperty(RaftsAgentProperties.RAFT_TYPE_AGENT_PROPERTY) ) {
                return agent.getName()+" controls";                
            }
            return null;
        }

        @Override        
        public JComponent open(AgentInfo agent, JComponent existingComponent) {
            String agentName = agent.getName();
            RaftsControlGui gui = new RaftsControlGui(agentName);
            gui.initGui();
            return gui.getGuiLayout();
        }

    }

}

==> org-lsst-ccs-subsystem-rafts-gui-1.10.5-sources.jar: org/lsst/ccs/subsystem/rafts/ui/jas/RaftsConsolePlugin.java <==
package org.lsst.ccs.subsystem.rafts.ui.jas;

import javax.swing.JComponent;
import org.lsst.ccs.bus.data.AgentInfo;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.base.OptionalPage;
import org.lsst.ccs.subsystem.rafts.data.RaftsAgentProperties;
import org.lsst.ccs.subsystem.rafts.ui.RaftsControlGui;
import org.lsst.ccs.subsystem.rafts.ui.RaftsMonitorGui;

/**
 *
 * @author tonyj
 */
@Plugin(name = "CCS Rafts Console Plugin",
        description = "CCS Rafts Console Plugin")
public class RaftsConsolePlugin extends ConsolePlugin {

    
    private final OptionalPage raftsMonitoringOptionalPage = new RaftsConsolePlugin.RaftsMonitoringOptionalPage();
    private final OptionalPage raftsControlsOptionalPage = new RaftsConsolePlugin.RaftsControlsOptionalPage();

    @Override
    public void initialize() {
        Console.getConsole().addOptionalPage(raftsMonitoringOptionalPage);
        Console.getConsole().addOptionalPage(raftsControlsOptionalPage);
    }


    static class RaftsMonitoringOptionalPage implements OptionalPage {

        @Override
        public boolean isAutoOpen() {
            return false;
        }

        @Override
        public String getPath() {
            return "CCS Subsystems/obsolete/Rafts/Monitoring";
        }

        @Override
        public String getPage(AgentInfo agent) {
            if (agent.hasAgentProperty(RaftsAgentProperties.RAFT_TYPE_AGENT_PROPERTY) ) {
                return agent.getName();
            }
            return null;
        }

        @Override        
        public JComponent open(AgentInfo agent, JComponent existingComponent) {
            String agentName = agent.getName();
            RaftsMonitorGui gui = new RaftsMonitorGui(agentName);
            gui.initGui();
            return gui.getGuiLayout();
        }

    }
    
    static class RaftsControlsOptionalPage implements OptionalPage {

        @Override
        public boolean isAutoOpen() {
            return false;
        }

        @Override
        public String getPath() {
            return "CCS Subsystems/Rafts/Controls";
        }

        @Override
        public String getPage(AgentInfo agent) {
            if (agent.hasAgentProperty(RaftsAgentProperties.RAFT_TYPE_AGENT_PROPERTY) ) {
                return agent.getName()+" controls";                
            }
            return null;
        }

        @Override        
        public JComponent open(AgentInfo agent, JComponent existingComponent) {
            String agentName = agent.getName();
            RaftsControlGui gui = new RaftsControlGui(agentName);
            gui.initGui();
            return gui.getGuiLayout();
        }

    }

}
